@@ -3,10 +3,13 @@
 The App class encapsulates a generic leaf task that can be executed asynchronously.
 """
 import logging
+import typeguard
 from abc import ABCMeta, abstractmethod
-from inspect import getsource
-from hashlib import md5
 from inspect import signature
+from typing import List, Optional, Union
+from typing_extensions import Literal
+
+from parsl.dataflow.dflow import DataFlowKernel
 
 logger = logging.getLogger(__name__)
 
@@ -39,7 +42,6 @@ class AppBase(metaclass=ABCMeta):
         self.__name__ = func.__name__
         self.func = func
         self.data_flow_kernel = data_flow_kernel
-        self.status = 'created'
         self.executors = executors
         self.cache = cache
         self.ignore_for_cache = ignore_for_cache
@@ -47,17 +49,6 @@ class AppBase(metaclass=ABCMeta):
             logger.error("App {} specifies invalid executor option, expects string or list".format(
                 func.__name__))
 
-        if cache is True:
-            try:
-                self.fn_source = getsource(func)
-            except OSError:
-                logger.warning("Unable to get source code for app caching. Recommend creating module")
-                self.fn_source = func.__name__
-
-            self.func_hash = md5(self.fn_source.encode('utf-8')).hexdigest()
-        else:
-            self.func_hash = func.__name__
-
         params = signature(func).parameters
 
         self.kwargs = {}
@@ -67,6 +58,8 @@ class AppBase(metaclass=ABCMeta):
             self.kwargs['stderr'] = params['stderr'].default
         if 'walltime' in params:
             self.kwargs['walltime'] = params['walltime'].default
+        if 'parsl_resource_specification' in params:
+            self.kwargs['parsl_resource_specification'] = params['parsl_resource_specification'].default
         self.outputs = params['outputs'].default if 'outputs' in params else []
         self.inputs = params['inputs'].default if 'inputs' in params else []
 
@@ -75,14 +68,20 @@ class AppBase(metaclass=ABCMeta):
         pass
 
 
-def python_app(function=None, data_flow_kernel=None, cache=False, executors='all', ignore_for_cache=None):
+@typeguard.typechecked
+def python_app(function=None,
+               data_flow_kernel: Optional[DataFlowKernel] = None,
+               cache: bool = False,
+               executors: Union[List[str], Literal['all']] = 'all',
+               ignore_for_cache: Optional[List[str]] = None,
+               join: bool = False):
     """Decorator function for making python apps.
 
     Parameters
     ----------
     function : function
         Do not pass this keyword argument directly. This is needed in order to allow for omitted parenthesis,
-        for example, `@python_app` if using all defaults or `@python_app(walltime=120)`. If the
+        for example, ``@python_app`` if using all defaults or ``@python_app(walltime=120)``. If the
         decorator is used alone, function will be the actual function being decorated, whereas if it
         is called with arguments, function will be None. Default is None.
     data_flow_kernel : DataFlowKernel
@@ -92,6 +91,10 @@ def python_app(function=None, data_flow_kernel=None, cache=False, executors='all
         Labels of the executors that this app can execute over. Default is 'all'.
     cache : bool
         Enable caching of the app call. Default is False.
+    join : bool
+        If True, this app will be a join app: the decorated python code must return a Future
+        (rather than a regular value), and and the corresponding AppFuture will complete when
+        that inner future completes.
     """
     from parsl.app.python import PythonApp
 
@@ -101,21 +104,40 @@ def python_app(function=None, data_flow_kernel=None, cache=False, executors='all
                              data_flow_kernel=data_flow_kernel,
                              cache=cache,
                              executors=executors,
-                             ignore_for_cache=ignore_for_cache)
+                             ignore_for_cache=ignore_for_cache,
+                             join=join)
         return wrapper(func)
     if function is not None:
         return decorator(function)
     return decorator
 
 
-def bash_app(function=None, data_flow_kernel=None, cache=False, executors='all', ignore_for_cache=None):
+@typeguard.typechecked
+def join_app(function=None,
+             data_flow_kernel: Optional[DataFlowKernel] = None,
+             cache: bool = False,
+             ignore_for_cache: Optional[List[str]] = None):
+    return python_app(function=function,
+                      data_flow_kernel=data_flow_kernel,
+                      cache=cache,
+                      ignore_for_cache=ignore_for_cache,
+                      join=True,
+                      executors=["_parsl_internal"])
+
+
+@typeguard.typechecked
+def bash_app(function=None,
+             data_flow_kernel: Optional[DataFlowKernel] = None,
+             cache: bool = False,
+             executors: Union[List[str], Literal['all']] = 'all',
+             ignore_for_cache: Optional[List[str]] = None):
     """Decorator function for making bash apps.
 
     Parameters
     ----------
     function : function
         Do not pass this keyword argument directly. This is needed in order to allow for omitted parenthesis,
-        for example, `@bash_app` if using all defaults or `@bash_app(walltime=120)`. If the
+        for example, ``@bash_app`` if using all defaults or ``@bash_app(walltime=120)``. If the
         decorator is used alone, function will be the actual function being decorated, whereas if it
         is called with arguments, function will be None. Default is None.
     data_flow_kernel : DataFlowKernel
