@@ -1,5 +1,7 @@
 from abc import ABCMeta, abstractmethod, abstractproperty
 
+from typing import Dict, Optional, Tuple
+
 
 class Channel(metaclass=ABCMeta):
     """For certain resources such as campus clusters or supercomputers at
@@ -36,12 +38,12 @@ class Channel(metaclass=ABCMeta):
     """
 
     @abstractmethod
-    def execute_wait(self, cmd, walltime=None, envs={}, *args, **kwargs):
+    def execute_wait(self, cmd: str, walltime: int = 0, envs: Dict[str, str] = {}) -> Tuple[int, Optional[str], Optional[str]]:
         ''' Executes the cmd, with a defined walltime.
 
         Args:
             - cmd (string): Command string to execute over the channel
-            - walltime (int) : Timeout in seconds, optional
+            - walltime (int) : Timeout in seconds
 
         KWargs:
             - envs (Dict[str, str]) : Environment variables to push to the remote side
@@ -54,7 +56,7 @@ class Channel(metaclass=ABCMeta):
         pass
 
     @abstractproperty
-    def script_dir(self):
+    def script_dir(self) -> str:
         ''' This is a property. Returns the directory assigned for storing all internal scripts such as
         scheduler submit scripts. This is usually where error logs from the scheduler would reside on the
         channel destination side.
@@ -67,8 +69,13 @@ class Channel(metaclass=ABCMeta):
         '''
         pass
 
+    # DFK expects to be able to modify this, so it needs to be in the abstract class
+    @script_dir.setter
+    def script_dir(self, value: str) -> None:
+        pass
+
     @abstractmethod
-    def push_file(self, source, dest_dir):
+    def push_file(self, source: str, dest_dir: str) -> str:
         ''' Channel will take care of moving the file from source to the destination
         directory
 
@@ -82,7 +89,7 @@ class Channel(metaclass=ABCMeta):
         pass
 
     @abstractmethod
-    def pull_file(self, remote_source, local_dir):
+    def pull_file(self, remote_source: str, local_dir: str) -> str:
         ''' Transport file on the remote side to a local directory
 
         Args:
@@ -96,7 +103,7 @@ class Channel(metaclass=ABCMeta):
         pass
 
     @abstractmethod
-    def close(self):
+    def close(self) -> bool:
         ''' Closes the channel. Clean out any auth credentials.
 
         Args:
@@ -109,7 +116,7 @@ class Channel(metaclass=ABCMeta):
         pass
 
     @abstractmethod
-    def makedirs(self, path, mode, exist_ok=False):
+    def makedirs(self, path: str, mode: int = 0o511, exist_ok: bool = False) -> None:
         """Create a directory.
 
         If intermediate directories do not exist, they will be created.
@@ -126,7 +133,7 @@ class Channel(metaclass=ABCMeta):
         pass
 
     @abstractmethod
-    def isdir(self, path):
+    def isdir(self, path: str) -> bool:
         """Return true if the path refers to an existing directory.
 
         Parameters
@@ -137,7 +144,7 @@ class Channel(metaclass=ABCMeta):
         pass
 
     @abstractmethod
-    def abspath(self, path):
+    def abspath(self, path: str) -> str:
         """Return the absolute path.
 
         Parameters
