@@ -2,7 +2,9 @@ from parsl.providers import AdHocProvider
 from parsl.channels import SSHChannel
 from parsl.executors import HighThroughputExecutor
 from parsl.config import Config
+from typing import Any, Dict
 
+user_opts: Dict[str, Dict[str, Any]]
 user_opts = {'adhoc':
              {'username': 'YOUR_USERNAME',
               'script_dir': 'YOUR_SCRIPT_DIR',
@@ -10,6 +12,7 @@ user_opts = {'adhoc':
              }
 }
 
+
 config = Config(
     executors=[
         HighThroughputExecutor(
