@@ -27,7 +27,7 @@ from parsl.executors.errors import ExecutorError
 from parsl.data_provider.files import File
 from parsl.errors import OptionalModuleMissing
 from parsl.executors.status_handling import BlockProviderExecutor
-from parsl.providers.provider_base import ExecutionProvider
+from parsl.providers.base import ExecutionProvider
 from parsl.providers import LocalProvider, CondorProvider
 from parsl.executors.workqueue import exec_parsl_function
 from parsl.process_loggers import wrap_with_logs
@@ -230,8 +230,6 @@ class WorkQueueExecutor(BlockProviderExecutor, putils.RepresentationMixin):
                  function_dir: Optional[str] = None):
         BlockProviderExecutor.__init__(self, provider=provider,
                                        block_error_handler=True)
-        self._scaling_enabled = True
-
         if not _work_queue_enabled:
             raise OptionalModuleMissing(['work_queue'], "WorkQueueExecutor requires the work_queue module.")
 
@@ -685,11 +683,6 @@ class WorkQueueExecutor(BlockProviderExecutor, putils.RepresentationMixin):
         logger.debug("Work Queue shutdown completed")
         return True
 
-    def scaling_enabled(self):
-        """Specify if scaling is enabled. Not enabled in Work Queue.
-        """
-        return self._scaling_enabled
-
     def run_dir(self, value=None):
         """Path to the run directory.
         """
