@@ -1,7 +1,6 @@
 from parsl.providers import AdHocProvider
 from parsl.channels import SSHChannel
 from parsl.executors import HighThroughputExecutor
-from parsl.addresses import address_by_query
 from parsl.config import Config
 
 from typing import Any, Dict
@@ -18,7 +17,6 @@ config = Config(
         HighThroughputExecutor(
             label='remote_htex',
             max_workers=2,
-            address=address_by_query(),
             worker_logdir_root=user_opts['adhoc']['script_dir'],
             provider=AdHocProvider(
                 # Command to be run before starting a worker, such as:
@@ -32,5 +30,5 @@ config = Config(
         )
     ],
     #  AdHoc Clusters should not be setup with scaling strategy.
-    strategy=None,
+    strategy='none',
 )
