@@ -20,7 +20,7 @@ config = Config(
             ),
         )
     ],
-    strategy=None,
+    strategy='none',
 )
 
 
