@@ -1,7 +1,6 @@
 from parsl import python_app
 import pytest
-from parsl.tests.configs.htex_local import fresh_config
-local_config = fresh_config()
+from parsl.tests.configs.htex_local import fresh_config as local_config
 
 
 @python_app
@@ -15,9 +14,9 @@ def compute_descript(size=1000):
 def test_1480(size=10**6):
     x = compute_descript(size=size)
 
-    # This should raise a TypeError: can't pickle memoryview objects
-    with pytest.raises(TypeError):
-        x.result()
+    # Before PR#1841 this would have raised a TypeError
+    # Now, with the threshold increased this should not trigger any error
+    assert len(x.result()) == size, "Lengths do not match"
 
 
 if __name__ == "__main__":
